gnome-ubuntu-multi-tool
=======================

A simple collection of tools that make running Gnome (3.10+) Ubuntu (14.04+) a little easier, especially on high-dpi hardware like the Retina MacbookPro.
